<a
  class="block select-none rounded-md p-3 leading-none no-underline outline-hidden text-sm font-medium transition-colors hover:bg-accent hover:text-accent-foreground focus:bg-accent focus:text-accent-foreground {% if class %}{{ class }}{% endif %}"
  {{ attrs }}
>
  {{ slot }}
</a>
