<label
    class="
    text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70
    {% if class %}
        {{ class }}
    {% endif %}
    "
    {{ attrs }}
>
    {{ slot}}
</label>
