<td
    class="
    p-2 align-middle [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-0.5
    {% if class %}
        {{ class }}
    {% endif %}
    "
    {{ attrs }}
  >
    {{ slot }}
</td>
