dependencies = {
    "a": [],
    "accordion": [],
    "alert": [],
    "alert_dialog": ["button"],
    "badge": [],
    "button": [],
    "card": [],
    "combobox": ["button", "popover"],
    "command": [],
    "command_dialog": ["command"],
    "dialog": ["button"],
    "checkbox": [],
    "dropdown_menu": [],
    "form": ["label"],
    "input": [],
    "label": [],
    "navigation_menu": [],
    "popover": [],
    "progress": [],
    "select": [],
    "sheet": ["button"],
    "separator": [],
    "table": [],
    "tabs": [],
    "toast": [],
    "textarea": [],
}
